# Contributors

Please look at [How to contribute](CONTRIBUTING.md) for information about how to contribute.

## Authors
- Thomas Hermann
- Dennis Reinsch

## Contributors
- Ferdinand Schlatt
- Fabian Kaupmann
- Micha Steffen Vosse
